@@ -1,4 +1,5 @@
-\donttest{# NOTE: to run the example. Download and load the newst version of cSEM.DGP
+\dontrun{
+# NOTE: to run the example. Download and load the newst version of cSEM.DGP
 # from GitHub using devtools::install_github("M-E-Rademaker/cSEM.DGP").
 
 # Create two data generating processes (DGPs) that only differ in how the composite
